import sys
import copy
from queue import PriorityQueue
import math

sys.setrecursionlimit(1000000)
def get_ints():
    return map(int,sys.stdin.readline().strip().split())

def get_string():
    return sys.stdin.readline().strip()





class DSU:
    def __init__(self, n):
        self.n = n
        self.parent = [-1 for i in range(n)]
        self.rank = [1 for i in range(n)]

    def find(self, n):
        update_list = []
        while (1):
            if (self.parent[n] < 0):
                for i in update_list:
                    self.parent[i] = n
                return n
            else:
                update_list.append(n)
                n = self.parent[n]

    def union(self, a, b):
        a = self.find(a)
        b = self.find(b)
        if (a == b):
            return False
        else:
            self.parent[b] += self.parent[a]
            self.parent[a] = b
            return True

    def union_by_rank(self, a, b):
        a = self.find(a)
        b = self.find(b)
        if (a == b):
            return False
        else:
            if (self.rank[a] > self.rank[b]):
                self.parent[a] += self.parent[b]
                self.rank[a] += self.rank[b]
                self.parent[b] = a

            else:
                self.parent[b] += self.parent[a]
                self.rank[b] += self.rank[a]
                self.parent[a] = b

            return True

if __name__=="__main__":
    pass


class BST_TreeNode:
    def __init__(self,val):
        self.data = val
        self.left = None
        self.right = None
        

class BinarySearchTree:
    def __init__(self):
        self.root = None
    
    def isNode(self,val):
        tempNode = self.root
        while(tempNode!=None):
            if(tempNode.data==val):
                return True
            elif(val>tempNode.data):
                tempNode = tempNode.right
            else:
                tempNode = tempNode.left
        return False
    
    def insertNode(self,val):
        newNode = BST_TreeNode(val)
        if(self.root==None):
            self.root = newNode
        else:
            prevtempNode = self.root
            tempNode = self.root
            right = False
            left = False
            while(tempNode!=None):
                prevtempNode = tempNode
                if(val>=tempNode.data):
                    right = True
                    left = False
                    tempNode = tempNode.right
                else:
                    left = True
                    right = False
                    tempNode = tempNode.left
            if(right==True):
                prevtempNode.right = newNode
            else:
                prevtempNode.left = newNode
    def findInorderSuccessor(self,node):
        while(node.left!=None):
            node = node.left            
        return node
    
    
    def __delete_one_node(self,node,val):
        if(val>node.data):
            node.right = self.__delete_one_node(node.right,val)
        elif(val<node.data):
            node.left = self.__delete_one_node(node.left,val)
         
        else:
            if(node.left==None and node.right==None):   
                return None
            elif(node.left==None):
                return node.right
            elif(node.right==None):
                return node.left
            else:
                insucNode = self.findInorderSuccessor(node.right)
                node.data = insucNode.data
                node.right = self.__delete_one_node(node.right,insucNode.data)
        return node
    
                
    def deleteNode(self,val):
        nodeFlag = self.isNode(val)
        if(not nodeFlag):
            return
        tempNode = self.root
        self.root = self.__delete_one_node(tempNode,val)
    
    def inorderTraversal(self,node,inlist):
        if(node==None): return
        self.inorderTraversal(node.left,inlist)
        inlist.append(node.data)
        self.inorderTraversal(node.right,inlist)
        
    def printTree(self,get=False):
        tempNode = self.root
        inlist = []
        self.inorderTraversal(tempNode,inlist)
        if(get==True):
            return inlist
        else:
            print(*inlist)




class AVL_TreeNode:
    def __init__(self,val):
        self.data = val
        self.left = None
        self.right = None
        self.height = 1

class AVLTree:
    def __init__(self):
        self.root = None
    
    def isNode(self,val):
        tempNode = self.root
        while(tempNode!=None):
            if(tempNode.data==val):
                return True
            elif(val>tempNode.data):
                tempNode = tempNode.right
            else:
                tempNode = tempNode.left
        return False
    
    def getHeight(self,node):
        if(node==None):
            return 0
        else:
            return node.height
    def balancefactor(self,node):
        left = 0
        right = 0
        if(node.left!=None):
            left = node.left.height
        if(node.right!=None):
            right = node.right.height
        return left-right
    
    def __insertNode(self,node,val):
        if(node==None):
            newNode = AVL_TreeNode(val)
            return newNode
        
        if(val>node.data):
            node.right = self.__insertNode(node.right,val)
        elif(val<node.data):
            node.left = self.__insertNode(node.left,val)
        
        node.height = 1+ max(self.getHeight(node.left),self.getHeight(node.right))
        
        bfactor = self.balancefactor(node)
    
        # Left Left Case
        if(bfactor>1 and val<node.left.data):
            node = self.rightrotate(node)
        
        # Left Right Case
        elif(bfactor>1 and val>node.left.data):
            node.left = self.leftrotate(node.left)
            node = self.rightrotate(node)
        
        # Right Right Case
        elif(bfactor<-1 and val>node.right.data):
            node = self.leftrotate(node)
        
        # Right Left Case
        elif(bfactor<-1 and val<node.right.data):
            node.right = self.rightrotate(node.right)
            node = self.leftrotate(node)
    
        return node
    
      
    def leftrotate(self,node):
        unbal = node
        temp = unbal.right
        unbal.right = temp.left
        temp.left = unbal
        
        unbal.height = 1+ max(self.getHeight(unbal.left),self.getHeight(unbal.right))
        temp.height = 1+ max(self.getHeight(temp.left),self.getHeight(temp.right))   
        
        return temp

    def rightrotate(self,node):
        unbal = node
        temp = unbal.left
        unbal.left = temp.right
        temp.right = unbal
        
        unbal.height = 1+ max(self.getHeight(unbal.left),self.getHeight(unbal.right))
        temp.height = 1+ max(self.getHeight(temp.left),self.getHeight(temp.right))        
        
        
        return temp
        
    def insertNode(self,val):
        self.root = self.__insertNode(self.root,val)
        
    def findInorderSuccessor(self,node):
        while(node.left!=None):
            node = node.left            
        return node
    
    def __checkBalance(self,node):
        if(node==None):
            return True
        bfactor = self.balancefactor(node)
       
        if(bfactor>1 or bfactor<-1):
            return False
        flg = True        
        flg = flg and self.__checkBalance(node.left)
        flg = flg and self.__checkBalance(node.right)
        return flg
    
    def __deleteNode(self,node,val):
        if(node==None): return 
        if(val>node.data):
            node.right = self.__deleteNode(node.right,val)
        elif(val<node.data):
            node.left = self.__deleteNode(node.left,val)
         
        else:
            if(node.left==None and node.right==None):   
                return None
            elif(node.left==None):
                return node.right
            elif(node.right==None):
                return node.left
            else:
                insucNode = self.findInorderSuccessor(node.right)
                node.data = insucNode.data
                node.right = self.__deleteNode(node.right,insucNode.data)

        if(node==None):
            return None
        node.height = 1 + max(self.getHeight(node.left),self.getHeight(node.right))
        bfactor = self.balancefactor(node)
        
        
        # Left Left
        if(bfactor>1 and self.balancefactor(node.left)>=0):
            node = self.rightrotate(node)
         
        # left Right   
        elif(bfactor>1 and self.balancefactor(node.left)<0):
            node.left = self.leftrotate(node.left)
            node = self.rightrotate(node)
            
        # Right Right
        elif(bfactor<-1 and self.balancefactor(node.right)<=0):
            node = self.leftrotate(node)
        
        # Right Left
        elif(bfactor<-1 and self.balancefactor(node.right)>0):
            node.right = self.rightrotate(node.right)
            node = self.leftrotate(node)
        
        return node
    
                
    def deleteNode(self,val):
        nodeFlag = self.isNode(val)
        if(not nodeFlag):
            return
        tempNode = self.root
        self.root = self.__deleteNode(tempNode,val)
    
    def inorderTraversal(self,node,inlist):
        if(node==None): return
        self.inorderTraversal(node.left,inlist)
        inlist.append(node.data)
        self.inorderTraversal(node.right,inlist)
    
    def bfstraversal(self,node,inlist):
        if(node==None): return
        tempNode = node
        que = [tempNode]
        while(len(que)!=0):
            newque = []
            for tnode in que:
                inlist.append(tnode.data if tnode!=None else "N")
                if(tnode!=None):
                    newque.append(tnode.left)
                    newque.append(tnode.right)
                    
            que = newque.copy()
                    
        
        
            
    def printTree(self,bfs=False,get=False):
        tempNode = self.root
        inlist = []
        if(not bfs):
            self.inorderTraversal(tempNode,inlist)
        else:
            self.bfstraversal(tempNode,inlist)
      
        if(get==True):
            return inlist
        else:
            print(*inlist)
        





import sys
import copy
from queue import PriorityQueue
import math

sys.setrecursionlimit(1000000)
def get_ints():
    return map(int,sys.stdin.readline().strip().split())

def get_string():
    return sys.stdin.readline().strip()


class LCA:
    def __init__(self, n=0, e=0):
        self.n = n
        self.e = e
        self.adj_list = [[] for _ in range(self.n)]

    def addEdge(self, u, v):
        self.adj_list[u].append(v)
        self.adj_list[v].append(u)

    def buildTree(self):
        for _ in range(self.e):
            u, v = map(int, input().split())
            u = u - 1
            v = v - 1
            self.addEdge(u, v)

    def dfs_level_parent(self, ni, level, parent, lev):
        def dfs(ni, level, parent, lev):
            level[ni] = lev

            for i in self.adj_list[ni]:
                if (i != parent[ni]):
                    parent[i] = ni
                    dfs(i, level, parent, lev + 1)

        dfs(ni, level, parent, lev)
        self.parent = parent
        self.level = level

    def lcaNaive(self, u, v, level, parent):
        if (level[u] > level[v]):
            u, v = v, u
        d = level[v] - level[u]
        for _ in range(d):
            v = parent[v]

        if (u == v):
            return u
        else:
            while (parent[u] != parent[v]):
                u = parent[u]
                v = parent[v]
            return parent[u]

    def binary_lifting(self, parent, max_level):
        max_level = int(math.log2(max_level))
        self.binary_list = [[-1 for _ in range(max_level + 1)] for __ in range(self.n)]
        for num, i in enumerate(parent):
            self.binary_list[num][0] = i

        for i in range(1, self.n):
            for j in range(1, max_level + 1):
                self.binary_list[i][j] = self.binary_list[self.binary_list[i][j - 1]][j - 1]

    def lcaFast(self, u, v, level, parent):
        if (level[u] > level[v]):
            u, v = v, u

        d = level[v] - level[u]

        while (d > 0):
            i = int(math.log2(d))
            v = self.binary_list[v][i]
            d = d - (1 << i)

        if (u == v):
            return u
        else:
            lev = level[u]
            while (lev > 0):
                i = int(math.log2(lev))
                if (self.binary_list[u][i] != self.binary_list[v][i]):
                    u = self.binary_list[u][i]
                    v = self.binary_list[v][i]
                else:
                    lev = lev - (1 << i)

            return self.binary_list[u][0]

    def distance_between_2_node(self, u, v):
        return self.level[u] + self.level[v] - 2 * self.level[(self.lcaFast(u, v, self.level, self.parent))]

if __name__=="__main__":
    pass


import sys
import copy
from queue import PriorityQueue
import math

sys.setrecursionlimit(1000000)
def get_ints():
    return map(int,sys.stdin.readline().strip().split())

def get_string():
    return sys.stdin.readline().strip()


class DSU:
    def __init__(self, n):
        self.n = n
        self.parent = [-1 for i in range(n)]
        self.rank = [1 for i in range(n)]

    def find(self, n):
        update_list = []
        while (1):
            if (self.parent[n] < 0):
                for i in update_list:
                    self.parent[i] = n
                return n
            else:
                update_list.append(n)
                n = self.parent[n]

    def union(self, a, b):
        a = self.find(a)
        b = self.find(b)
        if (a == b):
            return False
        else:
            self.parent[b] += self.parent[a]
            self.parent[a] = b
            return True

    def union_by_rank(self, a, b):
        a = self.find(a)
        b = self.find(b)
        if (a == b):
            return False
        else:
            if (self.rank[a] > self.rank[b]):
                self.parent[a] += self.parent[b]
                self.rank[a] += self.rank[b]
                self.parent[b] = a

            else:
                self.parent[b] += self.parent[a]
                self.rank[b] += self.rank[a]
                self.parent[a] = b

            return True


class DGraph:
    def __init__(self, n=0, e=0):
        self.n = n
        self.e = e
        self.INFINITY = 1000000007
        self.adj_list = [[] for _ in range(self.n)]
        self.edge_list = []

    def buildGraph(self):
        u, v = get_ints()
        u = u - 1
        v = v - 1
        self.adj_list[u].append(v)

    def build_kruskal_graph(self):
        for _ in range(self.e):
            u, v, w = get_ints()
            u = u - 1
            v = v - 1
            self.edge_list.append((u, v, w))

        self.edge_list.sort(key=lambda x: x[2])

    def msp_kruskal(self):
        dsu = DSU(self.n)
        cost = 0
        for u, v, w in self.edge_list:
            if (dsu.union_by_rank(u, v)):
                cost += w
        return cost

    def build_dijkstre_graph(self):
        for _ in range(self.e):
            u, v, w = get_ints()
            u = u - 1
            v = v - 1
            self.adj_list[u].append([w, v])

    def dijkstre_sssp(self, ni):
        dist = [self.INFINITY] * self.n
        dist[ni] = 0
        que = PriorityQueue()
        que.put([0, ni])
        while (que.qsize() != 0):
            w, v = que.get()
            for iw, i in self.adj_list[v]:
                if (dist[i] > (w + iw)):
                    que.put([iw + w, i])
                    dist[i] = w + iw
        return dist

    def buildBellmanford_graph(self):
        for _ in range(self.e):
            u, v, w = map(int, input().split())
            u = u - 1
            v = v - 1
            self.edge_list.append([u, v, w])

    def bellmanford_sssp(self, ni):
        dist = [self.INFINITY] * (self.n)
        dist[ni] = 0
        for _ in range(self.n - 1):
            flg = True
            for u, v, w in self.edge_list:
                if ((dist[u] != self.INFINITY) and (dist[v] > dist[u] + w)):
                    dist[v] = dist[u] + w
                    flg = False
            if flg:
                return dist
        return dist

    def build_Edmand_karp_graph(self):
        self.capacity = [[0 for _ in range(self.n)] for __ in range(self.n)]
        for _ in range(self.e):
            u, v, w = get_ints()
            u, v = u - 1, v - 1
            self.adj_list[u].append(v)
            self.adj_list[v].append(u)
            self.capacity[u][v] = w

    def edmand_karp_maxflow(self, s, t):
        def bfs(s, t):
            global parent
            parent = [-1 for i in range(self.n)]
            parent[s] = -2
            que = [[s, self.INFINITY]]
            while (que):

                curr, curr_flow = que.pop(0)
                for i in self.adj_list[curr]:
                    if (parent[i] == -1 and self.capacity[curr][i] != 0):
                        next_flow = min(self.capacity[curr][i], curr_flow)
                        que.append([i, next_flow])
                        parent[i] = curr
                        if (i == t):
                            return next_flow
            return 0

        max_flow = 0

        while (1):
            min_flow = bfs(s, t)
            if (min_flow == 0):
                break
            max_flow += min_flow
            path_v = t
            while (path_v != -2):
                # print(path_v,end = " ")  # path
                par = parent[path_v]
                self.capacity[par][path_v] -= min_flow
                self.capacity[path_v][par] += min_flow
                path_v = parent[path_v]
            # print()
        return max_flow

if __name__=="__main__":
    pass


import sys
import copy
from queue import PriorityQueue
import math

sys.setrecursionlimit(1000000)
def get_ints():
    return map(int,sys.stdin.readline().strip().split())

def get_string():
    return sys.stdin.readline().strip()

class Graph:
    def __init__(self, n=0, e=0):
        self.n = n
        self.e = e
        self.INFINITY = 1000000007
        self.indexed = 1
        self.adj_list = [[] for i in range(n)]

    def build_adjList(self, directed=False, indexed=1):
        self.indexed = indexed
        for _ in range(self.e):
            u, v = get_ints()

            u = u - self.indexed
            v = v - self.indexed

            self.adj_list[u].append(v)
            if (not directed):
                self.adj_list[v].append(u)

    def print(self, pl):
        for i in pl:
            print(i + self.indexed, end=" ")
        print()

    def dfs_one(self, n, visited=None, pl=None):

        def dfs(n, visited, pl):
            pl.append(n)
            visited[n] = True
            for i in self.adj_list[n]:
                if (not visited[i]):
                    dfs(i, visited, pl)

        if (visited == None):
            visited = [False] * self.n
        if (pl == None):
            pl = []
        dfs(n, visited, pl)
        return pl

    def dfs(self):
        visited = [False] * self.n
        pl = []
        for i in range(self.n):
            if (not visited[i]):
                self.dfs_one(i, visited, pl)

        return pl

    def bfs_one(self, n, visited=None, pl=None):

        def bfs(n, visited, pl):
            que = [n]
            visited[n] = True
            while (que):
                currNode = que[0]
                pl.append(currNode)
                que.pop(0)
                for i in self.adj_list[currNode]:
                    if (not visited[i]):
                        visited[i] = True
                        que.append(i)

        if (visited == None):
            visited = [False] * self.n
        if (pl == None):
            pl = []
        bfs(n, visited, pl)
        return pl

    def bfs(self):
        visited = [False] * self.n
        pl = []
        for i in range(self.n):
            if (not visited[i]):
                self.bfs_one(i, visited, pl)

        return pl

    def find_number_of_connected_components(self):
        visited = [False] * n
        count_components = 0
        for i in range(self.n):
            if (not visited[i]):
                count_components += 1
                self.dfs_one(i, visited)
        return count_components

    def single_source_shortest_path(self, n):
        visited = [False] * self.n
        shortest_path = [self.INFINITY] * self.n
        shortest_path[n] = 0

        def dfs(ni, visited, count, shortest_path):
            # shortest_path[ni] = count
            visited[ni] = True
            for i in self.adj_list[ni]:
                if (shortest_path[i] > (count + 1)):
                    shortest_path[i] = count + 1
                if (not visited[i]):
                    dfs(i, visited, count + 1, shortest_path)

        dfs(n, visited, 0, shortest_path)
        return shortest_path

    def isTree(self):
        nc = self.find_number_of_connected_components()
        if (nc == 1 and self.n == self.e + 1):
            return True
        else:
            return False

    def isBipartite(self, connected=False):
        visited = [False] * self.n
        color = [-1] * self.n
        color[0] = 0

        def dfs(ni, visited, c, color):
            visited[ni] = True
            for i in self.adj_list[ni]:
                if (not visited[i]):
                    color[i] = 1 - c
                    return dfs(i, visited, 1 - c, color)
                else:
                    if (color[i] == color[ni]):
                        return False
            return True

        if (not connected):
            ans = True
            for i in range(self.n):
                if (not visited[i]):
                    color[i] = 0
                    ans = ans and dfs(i, visited, 0, color)
            return ans

        return dfs(0, visited, 0, color)

    def isCycle(self):
        visited = [False] * self.n

        def dfs(ni, par):
            visited[ni] = True
            for child in self.adj_list[ni]:
                if (not visited[child]):
                    return dfs(child, ni)
                else:
                    if (child != par):
                        return True
            return False

        for i in range(self.n):
            if (not visited[i]):
                if (dfs(i, -1)):
                    return True
        return False

    def in_and_out(self):
        visited = [False] * self.n
        in_time = [-1] * self.n
        out_time = [-1] * self.n
        timer = [1]

        def dfs(ni, in_time, out_time, visited, timer):
            visited[ni] = True
            in_time[ni] = timer[0]
            timer[0] += 1
            for i in self.adj_list[ni]:
                if (not visited[i]):
                    dfs(i, in_time, out_time, visited, timer)

            out_time[ni] = timer[0]
            timer[0] += 1

        for i in range(self.n):
            if (not visited[i]):
                dfs(i, in_time, out_time, visited, timer)
        return in_time, out_time

    def diameter(self):
        visited = [False] * self.n
        temp = [0]
        node_v = [-1]

        def dfs(ni, visited, count, temp, node_v):
            visited[ni] = True
            if (count >= temp[0]):
                temp[0] = count
                node_v[0] = ni
            for i in self.adj_list[ni]:
                if (not visited[i]):
                    dfs(i, visited, count + 1, temp, node_v)

        for i in range(self.n):
            if (not visited[i]):
                dfs(0, visited, 0, temp, node_v)
        temp = [0]

        visited = [False] * self.n
        for i in range(self.n):
            if not visited[i]:
                dfs(node_v[0], visited, 0, temp, [0])

        return temp[0]

    def findBridges(self):
        visited = [False] * self.n
        in_time = [0] * self.n
        low = [0] * self.n
        timer = [0]
        ans = []

        def dfs(ni, visited, par, in_time, low, timer, ans):
            visited[ni] = True
            timer[0] += 1
            low[ni] = timer[0]
            in_time[ni] = timer[0]
            for _, i in enumerate(self.adj_list[ni]):
                if (i == par):
                    continue
                if (not visited[i]):
                    dfs(i, visited, ni, in_time, low, timer, ans)
                    if (low[i] > in_time[ni]):
                        ans.append([ni + self.indexed, i + self.indexed])
                    low[ni] = min(low[i], low[ni])
                else:
                    low[ni] = min(low[i], in_time[ni])

        dfs(0, visited, -1, in_time, low, timer, ans)
        return ans

    def findArticulation_vertex(self):
        visited = [False] * self.n
        in_time = [-1] * self.n
        low = [-1] * self.n
        ans = set()
        timer = [0]

        def dfs(ni, visited, par, in_time, low, timer, ans):
            visited[ni] = True
            children = 0
            in_time[ni] = timer[0]
            low[ni] = timer[0]
            timer[0] += 1

            for i in self.adj_list[ni]:
                if (i == par):
                    continue
                elif (not visited[i]):
                    dfs(i, visited, ni, in_time, low, timer, ans)
                    if (low[i] >= in_time[ni]):
                        if (ni != 0):
                            ans.add(ni + self.indexed)
                    low[ni] = min(low[ni], low[i])
                    children += 1
                else:
                    low[ni] = min(in_time[i], low[ni])

            if (children > 1 and par == -1):
                ans.add(0 + self.indexed)

        dfs(0, visited, -1, in_time, low, timer, ans)
        return ans

    def build_directed_graph_with_indegree(self, indexed=1):
        self.indexed = indexed
        indegree = [0] * (self.n)
        self.adj_list = [[] for _ in range(self.n)]
        for _ in range(self.e):
            u, v = get_ints()
            u = u - self.indexed
            v = v - self.indexed
            self.adj_list[u].append(v)
            indegree[v] += 1
        return indegree

    def topologicalsort(self, indegree):
        que = []
        ans = []
        for i in range(len(indegree)):
            if (indegree[i] == 0):
                que.append(i)
        while (que):
            curr = que.pop(0)
            ans.append(curr)
            for i in self.adj_list[curr]:
                indegree[i] -= 1
                if (indegree[i] == 0):
                    que.append(i)
        return ans

if __name__=="__main__":
    pass


from setuptools import setup, find_packages
import codecs
import os
from dsa_stl import __version__ as version

here = os.path.abspath(os.path.dirname(__file__))

VERSION = '0.0.7' #version
DESCRIPTION = 'DSA Algorithm'
LONG_DESCRIPTION = open('README.md').read()

# Setting up
setup(
    name="dsa_stl",
    version=VERSION,
    author="Aman Jaiswal (aman2000jaiswal)",
    author_email="<aman2000jaiswal14@gmail.com>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'dsa_stl','data structure','algorithms'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)